---
title: Translating the UDB
question: What are the guidelines for translating the UDB?
manual: gateway
volume: 3
slug: gl_udb
dependencies: ["gl_strategy", "gl_translate", "gl_ulb"]
status: drafted
tags: 
recommended: ["gl_notes", "check_udb"]
original_url:
credits: 
---
### Translation Theory for Translating the UDB

The Unlocked Dynamic Bible (UDB) is designed to be used in conjunction with the Unlocked Literal Bible (ULB) and the translationNotes as a tool for Bible translation. Unlike the ULB and unlike an end-user Bible, the UDB does not use figures of speech, idioms, abstract nouns, or grammatical forms that are difficult to translate into many languages. The purpose of the UDB is to show the plain meaning of all of those things wherever they occur in the ULB. Because the UDB lacks these things, it is not a beautiful end-user Bible. An end-user Bible will use the figures of speech and idioms that speak naturally and beautifully in the target language, but the UDB does not use them. As the Other Language translator uses both the UDB and the ULB together as his translation source, he will be able to see the figures of speech, idioms, and other forms of the original Bible in the ULB and also see what their meaning is in the UDB. Then he can use the figures of speech or other forms from the ULB that are clear and natural in his language. When the forms in the ULB are not clear or natural in his language, then he can choose other forms in his language that have the same meaning as the UDB translation or the Notes. When translating the UDB, please do not use idioms, figures of speech, or difficult grammatical forms in the Gateway Language translation. The purpose of the UDB is to change all of these problematic grammatical forms into more universal ones to make them easier to translate, and to make the meaning as clear as possible.

The UDB avoids using long or complex sentences. In many languages, long or complex sentences are unnatural and unclear. When translating the UDB, keep the sentences short and simple.

The UDB often fills in the participants when these are lacking in the original Bible and the ULB. In the original biblical languages, these participants could be left out and still understood by the reader. But in many languages these must be included for the translation to be clear and natural. When translating the UDB, therefore, be sure to include all of the participants that are there in the UDB.

### What method should be used to translate the UDB?

When translating the UDB, keep the English source open in front of you. This means that if you are translating using MAST methodology, do not use the step of blind drafting. The reason for this is that blind drafting is a method that translators use in order to produce natural target language translations. Through blind drafting, the translator replaces structures from the source language that would be unnatural in the target language with structures that are natural for that target language. But the UDB is a tool that carefully avoids certain structures that can be difficult to translate in some languages, as explained above. If the translator is using blind drafting, he might accidentally replace the simple structures of the UDB with structures that are natural in the target Gateway Language but unwanted in the UDB, such as idioms and figures of speech from the target GL. In order to guard against replacing these structures, it is best to translate the UDB with the English source text open to look at.

### Does Translation of the UDB Require a Back Translation?

We expect that the people translating the UDB into the Gateway Languages will be well-educated and have good theological training. They will be connected into church networks that will have adequate resources for checking the translations against the English source as well as the original biblical languages. For this reason, back translations of the UDB will usually not be necessary. The exception to this will be if the translation of the UDB is done by a secular translation company. In this case, we will need to also request a back translation into English, done according to the guidelines set forth in [Back Translation](https://git.door43.org/Door43/en-ta-checking-vol2/src/master/content/vol2_backtranslation.md) and following modules.

### Examples

The following are examples of ways that the text of the Bible can be unclear for some languages and what the UDB does to overcome those problems. When you translate the UDB, make sure that your translation of the UDB also avoids these problems.

#### Passive Voice

Passive voice is a grammatical construction that is common in Greek and English but it is not used in many other languages, so it can be very confusing. For that reason, it is not used in the UDB. In passive voice, the receiver of the action changes places with the actor. In English, the actor normally comes first in the sentence. But in passive voice, the receiver of the action comes first. Often, the actor is left unstated. In that case, the UDB will fill in the actor. See "Missing Participants" below.

For example, the ULB of Romans 2:24 says, "the name of God is dishonored among the Gentiles because of you." 

The action is "dishonor," the actors are "the Gentiles" (non-Jews), and the receiver of the action is "the name of God." The reason for the action is "because of you."

The UDB rearranges the verse to put the actor and the receiver of the action in a more normal order. It says, "The non-Jews speak evil about God because of the evil actions of you Jews." This is more clear for many languages. When you translate the UDB, make sure that you do not use any passive voice constructions.

#### Abstract Nouns

The ULB of Romans 2:10 says, "But praise, honor, and peace will come to everyone who practices good..." 

In this verse, the words "praise," "honor," "peace," and "good" are abstract nouns. That is, they are words that refer to things that we cannot see or touch. They are ideas. The ideas that these nouns express are closer to actions or descriptions than they are to things. In many languages, therefore, these ideas must be expressed by verbs or description words, not by nouns.

For this reason, the UDB expresses these nouns as actions or descriptions. It says, "But God will praise, honor, and give a peaceful spirit to every person who habitually does good deeds." 

When translating the UDB, avoid using abstract nouns. For more information on abstract nouns, see [Abstract Nouns](https://git.door43.org/Door43/en-ta-translate-vol2/src/master/content/figs_abstractnouns.md).

#### Long, Complex Sentences

The ULB translates the first three verses of Romans as one complex sentence. It says, "<sup>1</sup> Paul, a servant of Jesus Christ, called to be an apostle, set apart for the gospel of God, <sup>2</sup> which he promised beforehand by his prophets in the holy scriptures, <sup>3</sup> concerning his Son, who was born from the descendants of David according to the flesh."

The UDB breaks that into five sentences that are more simple in form. It says, "<sup>1</sup> I, Paul, who serve Christ Jesus, am writing this letter to all of you believers in the city of Rome. God chose me to be an apostle, and he appointed me in order that I should proclaim the good news that comes from him. <sup>2</sup> Long before Jesus came to earth, God promised that he would reveal this good news by means of what his prophets wrote in the sacred scriptures. <sup>3</sup> This good news is about his Son. As to his Son's physical nature, he was born a descendant of King David."

When translating the UDB, keep the sentences short and simple.

#### Missing Participants

In the ULB, Romans 1:1 says, "Paul, a servant of Jesus Christ, called to be an apostle, set apart for the gospel of God..." 

In this verse, there is a participant that is left unstated, but still understood. This participant is God. It is God who called Paul to be an apostle and who set him apart for the Gospel. In some languages, this participant must be stated. 

Therefore the UDB of Romans 1:1 says, "God chose me to be an apostle, and he appointed me in order that I should proclaim the good news that comes from him." 

When translating the UDB, be sure to include all of the participants that are there in the UDB.

#### Events out of Order

The ULB of Luke 2:6-7 says, "<sup>6</sup> Now it came about that while they were there, the time came for her to deliver her baby. <sup>7</sup> She gave birth to a son, her firstborn child, and she wrapped him snugly in strips of cloth. Then she put him in an animal feeding trough, because there was no room for them in a guest room." 

In some languages, events need to be told in the order in which they happened, or else the story will be confusing and hard to understand. People might understand from these verses that Mary delivered her baby outside in the street, and then looked for somewhere to stay and, after a long search, ended up putting him in an animal feeding trough. 

The UDB tells these events in the order in which they happened, so that it is clear that Mary was already in the shelter for animals when she gave birth. It says, "<sup>6-7</sup> When they arrived in Bethlehem, there was no place for them to stay in a place where visitors usually stayed. So they had to stay in a place where animals slept overnight. While they were there the time came for Mary to give birth and she gave birth to her first child, a son. She wrapped him in wide strips of cloth and placed him in the feeding place for the animals."

#### Figures of Speech

The ULB of Romans 2:21 says, "You who preach not to steal, do you steal?" 

This is a figure of speech called a rhetorical question. It is not a real question that is used to seek an answer. It is used to make a point. In this case, Paul is using it to scold his audience and to condemn their hypocrisy. Many languages do not use rhetorical questions, or they do not use them in this way. 

To show how to translate this meaning without a rhetorical question, the UDB says, "You who preach that people should not steal things, it is disgusting that you yourself steal things!" 
When you translate the UDB, be sure to not use rhetorical questions or other figures of speech. For more examples of figures of speech, see [Figures of Speech](https://git.door43.org/Door43/en-ta-translate-vol1/src/master/content/figs_intro.md) and the modules linked there.

#### Idioms

The ULB of Deuteronomy 32:10 says, "he guarded him as the apple of his eye." 

The word "apple" here does not refer to a kind of fruit, but instead refers to the pupil, the dark center of a person's eye. The phrase "the apple of his eye" is an idiom that refers to anything that is extremely precious to a person, or the one thing that is the most precious to a person. In many languages this idiom makes no sense, but they have other idioms that have this meaning. The Other Language translator should use one of these idioms from the target language in the OL translation, but there should be no idiom in the translation of the UDB.

To show the meaning of this verse, the UDB expresses this in plain language, without an idiom. It says, "He protected them and took care of them, as every person takes good care of his own eyes." 

The Notes add another way to translate this that makes the meaning clear. It says, "He protected the people of Israel as something most valuable and precious." When you translate the UDB, be sure that you do not use any idioms. Only use plain language that makes the meaning clear. For more information on idioms, see [Idiom](https://git.door43.org/Door43/en-ta-translate-vol1/src/master/content/figs_idiom.md).

For more examples of how the UDB avoids difficult grammatical constructions, idioms, and figures of speech, see the section of examples in [Translating the ULB](https://git.door43.org/Door43/en-ta-gl/src/master/content/gl_ulb.md).

